summaryrefslogtreecommitdiff
path: root/src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala
diff options
context:
space:
mode:
Diffstat (limited to 'src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala')
-rw-r--r--src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala b/src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala
index 735943b4ad..ed54328e30 100644
--- a/src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala
+++ b/src/compiler/scala/tools/nsc/symtab/AnnotationCheckers.scala
@@ -55,8 +55,8 @@ trait AnnotationCheckers {
/** Check that the annotations on two types conform. To do
* so, consult all registered annotation checkers. */
def annotationsConform(tp1: Type, tp2: Type): Boolean = {
- /* Finish quickly if there are no attributes */
- if (tp1.attributes.isEmpty && tp2.attributes.isEmpty)
+ /* Finish quickly if there are no annotations */
+ if (tp1.annotations.isEmpty && tp2.annotations.isEmpty)
true
else
annotationCheckers.forall(